#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MODF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MODF_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/modf.hpp>

#endif
